@@ -8,9 +8,7 @@ import (
 	"strings"
 	"testing"
 
-	etcd "github.com/coreos/etcd/clientv3"
-	"k8s.io/apiserver/pkg/registry/rest"
-
+	etcd "go.etcd.io/etcd/clientv3"
 	authorizationapi "k8s.io/api/authorization/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metainternal "k8s.io/apimachinery/pkg/apis/meta/internalversion"
@@ -21,8 +19,8 @@ import (
 	"k8s.io/apiserver/pkg/authentication/user"
 	apirequest "k8s.io/apiserver/pkg/endpoints/request"
 	"k8s.io/apiserver/pkg/registry/generic"
-	"k8s.io/apiserver/pkg/storage/etcd/etcdtest"
-	etcdtesting "k8s.io/apiserver/pkg/storage/etcd/testing"
+	"k8s.io/apiserver/pkg/registry/rest"
+	etcdtesting "k8s.io/apiserver/pkg/storage/etcd3/testing"
 	"k8s.io/kubernetes/pkg/api/legacyscheme"
 	kapi "k8s.io/kubernetes/pkg/apis/core"
 
@@ -52,6 +50,10 @@ func (f *fakeSubjectAccessReviewRegistry) Create(subjectAccessReview *authorizat
 	return nil, nil
 }
 
+func (f *fakeSubjectAccessReviewRegistry) CreateContext(ctx context.Context, subjectAccessReview *authorizationapi.SubjectAccessReview) (*authorizationapi.SubjectAccessReview, error) {
+	return nil, nil
+}
+
 func setup(t *testing.T) (etcd.KV, *etcdtesting.EtcdTestServer, *REST) {
 	server, etcdStorage := etcdtesting.NewUnsecuredEtcd3TestClientServer(t)
 	etcdStorage.Codec = legacyscheme.Codecs.LegacyCodec(schema.GroupVersion{Group: "image.openshift.io", Version: "v1"})
@@ -170,7 +172,7 @@ func TestCreateSuccessWithName(t *testing.T) {
 
 	_, err := client.Put(
 		context.TODO(),
-		etcdtest.AddPrefix("/imagestreams/default/somerepo"),
+		etcdtesting.AddPrefix("/imagestreams/default/somerepo"),
 		runtime.EncodeOrDie(legacyscheme.Codecs.LegacyCodec(imagev1.SchemeGroupVersion), initialRepo),
 	)
 	if err != nil {
@@ -244,7 +246,7 @@ func TestAddExistingImageWithNewTag(t *testing.T) {
 
 	_, err := client.Put(
 		context.TODO(),
-		etcdtest.AddPrefix("/imagestreams/default/somerepo"),
+		etcdtesting.AddPrefix("/imagestreams/default/somerepo"),
 		runtime.EncodeOrDie(legacyscheme.Codecs.LegacyCodec(imagev1.SchemeGroupVersion), existingRepo),
 	)
 	if err != nil {
@@ -253,7 +255,7 @@ func TestAddExistingImageWithNewTag(t *testing.T) {
 
 	_, err = client.Put(
 		context.TODO(),
-		etcdtest.AddPrefix("/images/"+imageID), runtime.EncodeOrDie(legacyscheme.Codecs.LegacyCodec(imagev1.SchemeGroupVersion), existingImage),
+		etcdtesting.AddPrefix("/images/"+imageID), runtime.EncodeOrDie(legacyscheme.Codecs.LegacyCodec(imagev1.SchemeGroupVersion), existingImage),
 	)
 	if err != nil {
 		t.Fatalf("Unexpected error: %v", err)
@@ -341,7 +343,7 @@ func TestAddExistingImageOverridingDockerImageReference(t *testing.T) {
 
 	_, err := client.Put(
 		context.TODO(),
-		etcdtest.AddPrefix("/imagestreams/default/newrepo"),
+		etcdtesting.AddPrefix("/imagestreams/default/newrepo"),
 		runtime.EncodeOrDie(legacyscheme.Codecs.LegacyCodec(imagev1.SchemeGroupVersion), newRepo),
 	)
 	if err != nil {
@@ -349,7 +351,7 @@ func TestAddExistingImageOverridingDockerImageReference(t *testing.T) {
 	}
 	_, err = client.Put(
 		context.TODO(),
-		etcdtest.AddPrefix("/images/"+imageID), runtime.EncodeOrDie(legacyscheme.Codecs.LegacyCodec(imagev1.SchemeGroupVersion), existingImage),
+		etcdtesting.AddPrefix("/images/"+imageID), runtime.EncodeOrDie(legacyscheme.Codecs.LegacyCodec(imagev1.SchemeGroupVersion), existingImage),
 	)
 	if err != nil {
 		t.Fatalf("Unexpected error: %v", err)
@@ -447,7 +449,7 @@ func TestAddExistingImageAndTag(t *testing.T) {
 
 	_, err := client.Put(
 		context.TODO(),
-		etcdtest.AddPrefix("/imagestreams/default/somerepo"),
+		etcdtesting.AddPrefix("/imagestreams/default/somerepo"),
 		runtime.EncodeOrDie(legacyscheme.Codecs.LegacyCodec(imagev1.SchemeGroupVersion), existingRepo),
 	)
 	if err != nil {
@@ -456,7 +458,7 @@ func TestAddExistingImageAndTag(t *testing.T) {
 
 	_, err = client.Put(
 		context.TODO(),
-		etcdtest.AddPrefix("/images/default/existingImage"),
+		etcdtesting.AddPrefix("/images/default/existingImage"),
 		runtime.EncodeOrDie(legacyscheme.Codecs.LegacyCodec(imagev1.SchemeGroupVersion), existingImage),
 	)
 	if err != nil {
@@ -530,7 +532,7 @@ func TestTrackingTags(t *testing.T) {
 
 	_, err := client.Put(
 		context.TODO(),
-		etcdtest.AddPrefix("/imagestreams/default/stream"),
+		etcdtesting.AddPrefix("/imagestreams/default/stream"),
 		runtime.EncodeOrDie(legacyscheme.Codecs.LegacyCodec(imagev1.SchemeGroupVersion), stream),
 	)
 	if err != nil {
